@@ -1,3 +1,7 @@
+"""
+Achilles是一个用来存储和管理模型文件的系统，后台地址为 https://achilles.insnail.com。
+"""
+
 import os
 import sys
 
@@ -5,6 +9,11 @@ import requests
 
 
 class ModelFile:
+    """
+    >>> model = ModelFile("ai-coeus", "nlu_model", "0.0.1")
+    >>> model.save_model("/root/data/models/ai-coeus-model.pkl")
+    """
+
     def __init__(self, project_slug: str, model_slug: str, version: str):
         self.project_slug = project_slug
         self.model_slug = model_slug
@@ -35,6 +44,6 @@ class ModelFile:
         else:
             r = os.system(f"wget {self.get_model_url()} -O {save_path}")
             if r != 0:
-                with open(save_path, "wb") as f:
+                with open(save_path, "wb") as fin:
                     content = self.get_model_content()
-                    f.write(content)
+                    fin.write(content)
