@@ -3,7 +3,11 @@ import os
 from typing import Any
 
 import yaml
-from pyapollo.apollo_client import ApolloClient
+
+from insnail_ai_tools.apollo_client import ApolloClient
+from insnail_ai_tools.meta import AutoReloadMixin
+
+# from pyapollo.apollo_client import ApolloClient
 
 
 class ConfigBase:
@@ -62,6 +66,7 @@ class ConfigBase:
 
     def fetch(self):
         for field in self.__annotations__.keys():
+            print(field, self._get_config_field(field))
             setattr(self, field, self._get_config_field(field))
 
 
@@ -81,28 +86,32 @@ class YamlConfig(ConfigBase):
             return getattr(self, field)
 
 
-class ApolloConfig(ConfigBase):
+class ApolloConfig(ConfigBase, AutoReloadMixin):
     def __init__(
         self,
         app_id: str,
         server_url: str,
         cluster: str = "default",
-        cycle_time: int = 300,
     ):
         logging.info(
             f"init config object [ApolloConfig], app_id: [{app_id}], server_url: [{server_url}], cluster: [{cluster}]"
         )
         self.apollo_client = ApolloClient(
             app_id=app_id,
-            config_server_url=server_url,
             cluster=cluster,
-            cycle_time=cycle_time,
+            config_server_url=server_url,
         )
-        # # 启动长监听
-        # self.apollo_client.start()
 
     def _get_config_field(self, field: str):
         value = self.apollo_client.get_value(field)
         if value is None:
             return getattr(self, field)
         return self._parse_field_type(self._get_field_type(field), value)
+
+    def fetch(self):
+        print("清除Apollo缓存")
+        self.apollo_client._cache = {}
+        self.apollo_client.cache_config()
+        print("更新Apollo配置信息")
+        for field in self.__annotations__.keys():
+            setattr(self, field, self._get_config_field(field))
