@@ -12,6 +12,7 @@ class RuleContentTypeChoices(StrChoicesMixin):
     image = "image"
     voice = "voice"
     record = "record"
+    meeting_voice = "meeting_voice"
     all = "all"
 
 
@@ -44,9 +45,9 @@ class MessageCheckRule(mongoengine.DynamicDocument, MultiDatabaseMixin):
     level = mongoengine.IntField(
         verbose_name="风险等级", default=1, help_text="风险等级，等级越高越紧急"
     )
-    notify_mode = mongoengine.ListField(
-        mongoengine.StringField(choices=NotifyModeChoices.choices()),
+    notify_mode = mongoengine.StringField(
         verbose_name="通知方式",
+        choices=NotifyModeChoices.choices(),
         default=NotifyModeChoices.RECORD,
     )
     is_legal = mongoengine.BooleanField(
@@ -69,6 +70,10 @@ class MessageCheckRule(mongoengine.DynamicDocument, MultiDatabaseMixin):
         mongoengine.EmbeddedDocumentField(RuleMeta),
         verbose_name="除外规则列表",
     )
+    exclude_black_user_id = mongoengine.BooleanField(
+        verbose_name="剔除违禁微信名单", default=False
+    )
+
     meta = {
         "collection": "message_check_rule",
         "indexes": [
@@ -78,9 +83,28 @@ class MessageCheckRule(mongoengine.DynamicDocument, MultiDatabaseMixin):
             "is_legal",
             "illegal_type",
             "rule_type",
+            "exclude_black_user_id",
         ],
         "abstract": True,
     }
 
     def __str__(self):
         return f"{self.content_type}_{self.illegal_type}_{self.role}"
+
+
+class WecomUserExtraInfo(mongoengine.DynamicDocument, MultiDatabaseMixin):
+    """
+    用户额外信息的库，一般在质检中用到，比如收集用户个人的微信号、手机号等
+    """
+
+    user_id = mongoengine.StringField(verbose_name="用户ID", primary_key=True)
+    user_name = mongoengine.StringField(verbose_name="用户名称")
+
+    black_wechat_id = mongoengine.ListField(
+        mongoengine.StringField(), verbose_name="违禁微信列表"
+    )
+
+    meta = {
+        "collection": "wecom_user_extra_info",
+        "abstract": True,
+    }
